@@ -107,7 +107,7 @@ class TaskData:
         self._train_data, self._eval_data = None, None
 
     def train_data(self):
-        if self._train_data is not None:
+        if not self._train_data:
             self._train_data = TaskDataset(self._data_args,
                                            tokenizer=self._tokenizer,
                                            processor=self._processor,
